@@ -390,7 +390,6 @@ classicthemerestorerjso.ctr = {
 	}
 
 	if (this.appversion < 47) {
-	  document.getElementById('ctraddon_pw_hiderecentbm').style.visibility = 'collapse';
 	  document.getElementById('ctraddon_pw_hideeditbm').style.visibility = 'collapse';
 	  document.getElementById('ctraddon_pw_dblclnewtabdes').style.visibility = 'collapse';
 	}
@@ -406,6 +405,7 @@ classicthemerestorerjso.ctr = {
 	  document.getElementById('ctraddon_pw_anewtaburlpcb').style.visibility = 'collapse';
 	  document.getElementById('ctraddon_pw_anewtaburlpurlbox').style.visibility = 'collapse';
 	  document.getElementById('ctraddon_pw_cresultshbox').style.visibility = 'collapse';
+	  document.getElementById('ctraddon_pw_aboutpages').style.visibility = 'collapse';
 	}
 
 	if (this.appversion >= 48) {
@@ -413,6 +413,11 @@ classicthemerestorerjso.ctr = {
 	  document.getElementById('ctraddon_pw_urlbar_uc_desc').style.visibility = 'collapse';
 	}
 	
+	if (this.appversion < 49) {
+	  document.getElementById('ctraddon_pw_hiderecentbm').style.visibility = 'collapse';
+	  document.getElementById('ctraddon_pw_hiderecentbmdes').style.visibility = 'collapse';
+	}
+	
 	if (this.appversion >= 49) {
 	  document.getElementById('ctraddon_pw_loopcallgb').style.visibility = 'collapse';
 	}
@@ -422,6 +427,7 @@ classicthemerestorerjso.ctr = {
 	  document.getElementById('ctraddon_pw_findbarhlgb').style.visibility = 'collapse';
 	  document.getElementById('ctraddon_pw_flywebgb').style.visibility = 'collapse';
 	  document.getElementById('ctraddon_pw_autocompl_it2').style.visibility = 'collapse';
+	  document.getElementById('ctraddon_pw_oldplacesbut').style.visibility = 'collapse';
 	}
 	
 	if (this.appversion >= 50) {
@@ -430,6 +436,7 @@ classicthemerestorerjso.ctr = {
 
 	if (this.appversion < 51) {
 	  document.getElementById('ctraddon_pw_oneoffsearchgb').style.visibility = 'collapse';
+	  document.getElementById('ctraddon_pw_hideurlzoom').style.visibility = 'collapse';
 	}
 	
 	function PrefListener(branch_name, callback) {
@@ -1191,6 +1198,9 @@ classicthemerestorerjso.ctr = {
 	this.prefs.setBoolPref("hideurlsrg",true);
 
 	this.prefs.setBoolPref("oldsearch",true);
+	
+	if(this.appversion >= 50)
+	  this.prefs.setBoolPref("oldplacesbut",true);
 
 	if(this.appversion >= 48)
 	  this.prefs.setBoolPref("altautocompl",true);
