@@ -40,6 +40,7 @@ pref("extensions.classicthemerestorer.nbcompact",false);
 pref("extensions.classicthemerestorer.statusbar",true);
 pref("extensions.classicthemerestorer.noconicons",false);
 pref("extensions.classicthemerestorer.altoptions",'options_default');
+pref("extensions.classicthemerestorer.aboutpages",false);
 pref("extensions.classicthemerestorer.svgfilters",false);
 pref("extensions.classicthemerestorer.combrelstop",false);
 pref("extensions.classicthemerestorer.activndicat",false);
@@ -76,8 +77,8 @@ pref("extensions.classicthemerestorer.am_highlight",false);
 pref("extensions.classicthemerestorer.am_buticons",false);
 pref("extensions.classicthemerestorer.am_hovshowb",false);
 pref("extensions.classicthemerestorer.alt_addonsp",false);
-pref("extensions.classicthemerestorer.hiderecentbm",false);
 pref("extensions.classicthemerestorer.hideeditbm",false);
+pref("extensions.classicthemerestorer.oldplacesbut",false);
 pref("extensions.classicthemerestorer.bmbutpanelm",false);
 pref("extensions.classicthemerestorer.bmbunsortbm",false);
 pref("extensions.classicthemerestorer.bmbunsortbm2",true);
@@ -128,12 +129,14 @@ pref("extensions.classicthemerestorer.hideprbutton",false);
 pref("extensions.classicthemerestorer.urlbardropm",false);
 pref("extensions.classicthemerestorer.urlbardropm2",false);
 pref("extensions.classicthemerestorer.altreaderico",false);
+pref("extensions.classicthemerestorer.hideurlzoom",false);
 pref("extensions.classicthemerestorer.altautocompl",false);
 pref("extensions.classicthemerestorer.autocompl_it",false);
 pref("extensions.classicthemerestorer.autocompl_it2",false);
 pref("extensions.classicthemerestorer.autocompl_hlb",false);
 pref("extensions.classicthemerestorer.autocompl_hlu",false);
 pref("extensions.classicthemerestorer.autocompl_hli",false);
+pref("extensions.classicthemerestorer.autocompl_hln",false);
 pref("extensions.classicthemerestorer.autocompl_sep",false);
 pref("extensions.classicthemerestorer.autocompl_rhl",false);
 
